module R10.Svg.Others exposing (mobileWithPerson, mountain, spinnerRotation, greenCheck, checkMark, errorLens, errorTriangle, letterClosed, letterOpen, rocket, paperPlane, externalLink)

{-|

@docs mobileWithPerson, mountain, spinnerRotation, greenCheck, checkMark, errorLens, errorTriangle, letterClosed, letterOpen, rocket, paperPlane, externalLink

-}

import Element.WithContext exposing (..)
import R10.Color.Utils
import R10.Context exposing (..)
import R10.Svg.Utils
import Svg
import Svg.Attributes as SA


{-| -}
spinnerRotation : List (Attribute (R10.Context.ContextInternal z) msg) -> Int -> String -> Element (R10.Context.ContextInternal z) msg
spinnerRotation attrs size colorString =
    let
        idElement =
            "r10_spinner"

        speed =
            "0.6s"
    in
    R10.Svg.Utils.wrapperWithViewbox attrs
        "0 0 38 38"
        size
        [ Svg.defs []
            [ Svg.linearGradient
                [ SA.id idElement, SA.x1 "8%", SA.x2 "65.7%", SA.y1 "0%", SA.y2 "23.9%" ]
                [ Svg.stop
                    [ SA.offset "0%", SA.stopColor colorString, SA.stopOpacity "0" ]
                    []
                , Svg.stop
                    [ SA.offset "63.1%", SA.stopColor colorString, SA.stopOpacity ".6" ]
                    []
                , Svg.stop
                    [ SA.offset "100%", SA.stopColor colorString ]
                    []
                ]
            ]
        , Svg.g [ SA.fill "none", SA.fillRule "evenodd", SA.transform "translate(1 1)" ]
            [ Svg.path
                [ SA.d "M36 18C36 8 28 0 18 0"
                , SA.stroke <| "url(#" ++ idElement ++ ")"
                , SA.strokeWidth "2"
                ]
                [ Svg.animateTransform
                    [ SA.attributeName "transform"
                    , SA.dur speed
                    , SA.from "0 18 18"
                    , SA.repeatCount "indefinite"
                    , SA.to "360 18 18"
                    , SA.type_ "rotate"
                    ]
                    []
                ]
            , Svg.circle [ SA.cx "36", SA.cy "18", SA.fill colorString, SA.r "1" ]
                [ Svg.animateTransform
                    [ SA.attributeName "transform"
                    , SA.dur speed
                    , SA.from "0 18 18"
                    , SA.repeatCount "indefinite"
                    , SA.to "360 18 18"
                    , SA.type_ "rotate"
                    ]
                    []
                ]
            ]
        ]


{-| -}
mobileWithPerson : List (Attribute (R10.Context.ContextInternal z) msg) -> Color -> Int -> Element (R10.Context.ContextInternal z) msg
mobileWithPerson attrs cl size =
    let
        clHex =
            R10.Color.Utils.toCssRgba cl
    in
    R10.Svg.Utils.wrapperWithViewbox attrs
        "0 0 209 160"
        size
        [ Svg.path [ SA.fill "#F2F2F2", SA.d "M102.7 160c45.57 0 82.5-4.03 82.5-9s-36.93-9-82.5-9c-45.56 0-82.5 4.03-82.5 9s36.94 9 82.5 9z" ] []
        , Svg.path [ SA.fill "#181818", SA.stroke "#CBCBCB", SA.strokeWidth ".3", SA.d "M49.14 150.55h0a6.45 6.45 0 01-4.42-1.76 6 6 0 01-1.83-4.26V7.13v0a5.84 5.84 0 011.83-4.26 6.27 6.27 0 014.42-1.77h57.79a6.44 6.44 0 014.42 1.77 6.04 6.04 0 011.83 4.26v137.4c0 1.6-.66 3.13-1.84 4.25a6.37 6.37 0 01-4.41 1.77h-57.8z" ] []
        , Svg.path [ SA.fill "#3F3D56", SA.d "M111.07 9v133.7a6 6 0 01-6 6H50.78a6 6 0 01-6.01-6V9a6 6 0 016-6h8.13v1.04A4.95 4.95 0 0063.86 9h27.6a4.9 4.9 0 004.55-3c.26-.62.4-1.28.4-1.95V3h8.65a6.01 6.01 0 016 6z" ] []
        , Svg.path [ SA.fill "#F2F2F2", SA.d "M59.9 26.72a1.44 1.44 0 100-2.89 1.44 1.44 0 000 2.89z" ] []
        , Svg.path [ SA.fill clHex, SA.d "M94.88 7.62c-.15.14-.32.28-.49.4a25.83 25.83 0 0016.68 12.42v-.65a25.22 25.22 0 01-16.2-12.17zM82.54 8.99h-.67a37.47 37.47 0 0029.2 23.32v-.64A36.83 36.83 0 0182.54 8.99z" ] []
        , Svg.path [ SA.fill "#F2F2F2", SA.d "M55.16 35.96h-.38v-.37h-.07v.37h-.38v.08h.38v.37h.07v-.37h.38v-.08zM80.52 17.2h-.37v-.38h-.08v.37h-.37v.08h.37v.37h.08v-.37h.37v-.08zM58.87 50.81h-.38v-.37h-.07v.37h-.38v.08h.38v.37h.07v-.37h.38v-.08zM76.2 39.88h-.38v-.37h-.08v.37h-.37v.07h.37v.38h.08v-.38h.37v-.07zm24.74 6.81h-.37v-.38h-.08v.38h-.37v.07h.37v.38h.08v-.38h.37v-.07z" ] []
        , Svg.path [ SA.fill "#FF6584", SA.d "M96.61 29.6a.82.82 0 100-1.64.82.82 0 000 1.65z" ] []
        , Svg.path [ SA.fill "#E6E6E6", SA.d "M67.06 48.13l-.47.07c.14.94.26 1.9.34 2.84l.48-.04c-.09-.96-.2-1.93-.35-2.87zm-1.28-5.64l-.46.14c.28.9.52 1.83.73 2.76l.46-.1a42.2 42.2 0 00-.73-2.8zm-2.05-5.41l-.43.2c.4.86.77 1.75 1.1 2.64l.45-.17c-.34-.9-.72-1.8-1.12-2.67zm-2.76-5.07l-.4.25c.5.8 1 1.63 1.45 2.46l.42-.22a47.8 47.8 0 00-1.47-2.49zm-3.44-4.65l-.36.31a42.3 42.3 0 011.78 2.24l.38-.28a41.22 41.22 0 00-1.8-2.27zm-4.03-4.13l-.32.35c.7.63 1.4 1.3 2.06 1.98l.34-.33a41.59 41.59 0 00-2.09-2zm-4.57-3.55l-.26.39c.78.53 1.56 1.1 2.31 1.68l.3-.38a42.83 42.83 0 00-2.35-1.7zm-4.15-2.48v.54c.5.26.98.53 1.46.8l.24-.4c-.56-.32-1.13-.63-1.7-.93zm22.17 75.48c.08-.46.15-.94.2-1.4l.48.06-.21 1.41-.47-.07zm-1.32 5.56l.45.14c.28-.91.54-1.85.76-2.79l-.46-.1a42.5 42.5 0 01-.75 2.75zm-2.07 5.33l.43.2c.4-.87.79-1.76 1.14-2.66l-.45-.17a40.7 40.7 0 01-1.12 2.63zm-2.79 5l.4.26c.52-.8 1.02-1.64 1.5-2.48l-.42-.23c-.46.83-.96 1.65-1.48 2.45zm-3.45 4.56l.36.31a43.5 43.5 0 001.82-2.25l-.38-.28a41.8 41.8 0 01-1.8 2.22zm-4.04 4.06l.32.35a39.3 39.3 0 002.1-1.98l-.33-.33c-.67.67-1.37 1.33-2.09 1.95zm-4.54 3.46l.26.4c.8-.53 1.6-1.1 2.36-1.68l-.29-.38a41.6 41.6 0 01-2.33 1.66zm-2.21 1.9c-.57.33-1.16.64-1.75.94v-.54a43.4 43.4 0 001.52-.8l.23.4zm20.56-68.59h.47v1.43l-.47-.01v-1.42z" ] []
        , Svg.path [ SA.fill "#fff", SA.d "M46.86 65.21h48.51A13.61 13.61 0 01109 78.82v1.8H60.47a13.61 13.61 0 01-13.6-13.6v-1.8z" ] []
        , Svg.path [ SA.fill clHex, SA.d "M66.7 89.42a16.5 16.5 0 100-33 16.5 16.5 0 000 33z", SA.opacity ".2" ] []
        , Svg.path [ SA.fill clHex, SA.d "M66.7 84.54a11.62 11.62 0 100-23.24 11.62 11.62 0 000 23.24z", SA.opacity ".2" ] []
        , Svg.path [ SA.fill clHex, SA.d "M66.7 80.59a7.67 7.67 0 100-15.34 7.67 7.67 0 000 15.34z" ] []
        , Svg.path [ SA.fill "#fff", SA.d "M68.1 71.26a1.4 1.4 0 10-2.28 1.08l-.5 3.6h2.78l-.51-3.6a1.4 1.4 0 00.51-1.08z" ] []
        , Svg.path [ SA.fill "#2F2E41", SA.d "M143.78 14s-4.6-4.13-10.79 3.64c-6.19 7.77-15.86 11.58-18.08 14.6 0 0 9.2-3.81 12.37-5.4 3.17-1.59 3.01-1.27 3.01-1.27s-4.28 3.02-5.07 6.03c-.8 3.01-.16 5.55-1.59 8.56-1.42 3.02 27.28 2.07 27.28 2.07s2.86-4.92 2.06-10c-.79-5.07-.31-17.6-9.2-18.24z" ] []
        , Svg.path [ SA.fill "#F4C6C6", SA.d "M135.08 26.97s1 7-3.29 8.57c-4.29 1.57-2.72 3.71-2.72 3.71l6.44 3.15 6.85-2.15 2.29-3.42s-3.72-.86-2.72-3.43c1-2.58 1.29-3.43 1.29-3.43l-8.14-3z" ] []
        , Svg.path [ SA.fill "#000", SA.d "M135.08 26.97s1 7-3.29 8.57c-4.29 1.57-2.72 3.71-2.72 3.71l6.44 3.15 6.85-2.15 2.29-3.42s-3.72-.86-2.72-3.43c1-2.58 1.29-3.43 1.29-3.43l-8.14-3z", SA.opacity ".1" ] []
        , Svg.path [ SA.fill "#F4C6C6", SA.d "M153.08 46.97s-1 13.15-.72 13.72c.3.57 0 20.43 0 20.43s2 10.72-.57 11.29c-2.57.57-2-12-2-12l-2.57-16.58.29-16.43 5.57-.43z" ] []
        , Svg.path [ SA.fill "#000", SA.d "M153.08 46.97s-1 13.15-.72 13.72c.3.57 0 20.43 0 20.43s2 10.72-.57 11.29c-2.57.57-2-12-2-12l-2.57-16.58.29-16.43 5.57-.43z", SA.opacity ".1" ] []
        , Svg.path [ SA.fill "#F4C6C6", SA.d "M125.22 86.55s-4.72 17.86-4.58 26.58c.15 8.71 2 20.86 2 20.86s.3 5.28-.14 5.86c-.43.57 2.14 3 2.14 3l2.72-1.57 1-1.15v-1s-1.57-4.86-.29-8.71c1.3-3.86 2-13.58.72-16.58l8.86-26.29-12.43-1z" ] []
        , Svg.path [ SA.fill "#2F2E41", SA.d "M124.93 140.56s-1.71-2.14-2.86-1.43c-1.14.72-3 5.57-3 5.57s-6.43 6.15-1.85 6.43c4.57.29 6.57-1.28 7.14-2.42.57-1.15 5.86-4.15 5.86-4.15s-.57-5.43-1.43-5.57c-.86-.14-2.14 2.14-2.14 2.14l-1.72-.57z" ] []
        , Svg.path [ SA.fill "#F4C6C6", SA.d "M140.8 87.7v17.71c0 2.15.15 4.3.42 6.43.43 3.14-2.43 26.58-2.43 26.58l.29 4.14 3.57-.28.43-3.58 5.14-15.71s1.72-9.58.86-13.15c-.86-3.57 4.43-26.43 4.43-26.43l-12.72 4.28z" ] []
        , Svg.path [ SA.fill "#2F2E41", SA.d "M137.93 141.56l1.06-.23s.8-1.77 1.8-1.34c.7.32 1.37.72 1.99 1.2l.44.8s1 2.14 2.29 3.57c1.28 1.43 2.71 4.57.57 4.86-2.15.29-5 .43-5.86-.29-.86-.71-.29-1.85-1.14-2.14-.86-.28-1.58-1.14-1.43-1.43.14-.28.28-5 .28-5z" ] []
        , Svg.path [ SA.fill "#F4C6C6", SA.d "M140.8 31.89a6.35 6.35 0 100-12.7 6.35 6.35 0 000 12.7z" ] []
        , Svg.path [ SA.fill clHex, SA.d "M128.79 36.68l1.89-.66s-.75 1.23 3.25 1.95c4 .71 8.15.97 10-1.38 0 0 .72-.34 1.72.66s1.57.72 1.57.72l-.71 3.71-1.43 6.86-1.86 5.15-5.29-1.15-5.71-4.14-2.15-5.57v-5.15l-1.28-1z" ] []
        , Svg.path [ SA.fill clHex, SA.d "M146.22 38.68l1.43-1s4.86.86 5.14 3.15l-3.71 7.14c.76 1.99.7 4.2-.14 6.14-1.43 3.3-1.29 4-1.29 4l-1 4.3-18.15 1.42s-.71-1.71-1-2c-.28-.29-.28-1.29 0-1.29.29 0 0-.42-.28-.85-.29-.43-.43-.57 0-1.15.43-.57-.72-5.71-.72-5.71v-5.57l-4.86-6.43s1.72-2.58 2.58-2.86c.85-.29 4.93-1.41 4.93-1.41l.92 1.35 1.3 10.35 1.85 6.28 7.82-1.33 3.04-5.1 2-6 .14-3.43z" ] []
        , Svg.path [ SA.fill clHex, SA.d "M151.65 39.97l1.14.86s1 8 .72 8.57c-.29.57-5.29 1.14-5.43.86-.14-.29 3.57-10.3 3.57-10.3z" ] []
        , Svg.path [ SA.fill "#2F2E41", SA.d "M128.07 35.97l1.43 9.43s-1.28 14-1 16.86l.29.86s-.57-.29-.72.28c-.14.57 0 2.43 0 2.43s-.85.86-1.14 5.57c-.28 4.72-3.71 16-2.43 16.44 1.29.42 9 2.57 13.15 2.14 4.14-.43 19-5.43 18.86-6.72-.14-1.28-7.29-19.43-7.29-19.43s-1.28-2.14-1.28-2.43c0-.28 1.71-1.43 1.28-2.57-.43-1.14-2.71-13.15-2.71-13.15l1.57-8.57-2.15-.57-1.57 8.29s-6.14 3-12.57.28l-1.43-9.71-2.29.57zm6.88-14.99s10.57 7.29 13.43 4c2.86-3.29-5-6.14-5-6.14l-6.57-.72-1.86 2.86z" ] []
        , Svg.path [ SA.fill clHex, SA.d "M118.52 98.5a5.57 5.57 0 10-1.75-2.17l-14.58 12.14-1.94-2.3-.88.58-.97-1.15.8-.67-.97-1.16-1.24 1.05.6.71-1.33 1.12-.6-.7-1.95 1.63.9 1.07.7-.6.98 1.15-.89.75 1.8 2.13-2.13 1.79 2.16 2.57 21.3-17.94zm3.64-8.14a3.69 3.69 0 11-.63 7.34 3.69 3.69 0 01.63-7.34z" ] []
        , Svg.path [ SA.fill "#F4C6C6", SA.d "M120.64 48.69s1 13.14.72 13.71c-.29.57 0 20.43 0 20.43s-2 10.72.57 11.3c2.57.56 2-12.01 2-12.01l2.57-16.57-.28-16.44-5.58-.42z" ] []
        , Svg.path [ SA.fill clHex, SA.d "M122.79 40.4l-1.15.43s-2.14 9-1.57 9c.58 0 7.43.86 7.43.57 0-.29-1.28-7.29-1.28-7.29l-3.43-2.71z" ] []
        ]


{-| -}
mountain : List (Attribute (R10.Context.ContextInternal z) msg) -> Int -> Element (R10.Context.ContextInternal z) msg
mountain attrs size =
    R10.Svg.Utils.wrapperWithViewbox attrs
        "0 0 152 148"
        size
        [ Svg.g [ SA.fill "none" ]
            [ Svg.mask [ SA.id "a", SA.width "152", SA.height "152", SA.x "0", SA.y "0", SA.maskUnits "userSpaceOnUse" ]
                [ Svg.path [ SA.fill "#fff", SA.d "M73.8 148A74 74 0 1 0 73.7.2a74 74 0 0 0 .1 147.8z" ] []
                ]
            , Svg.g [ SA.mask "url(#a)" ]
                [ Svg.path [ SA.fill "#98C9F2", SA.d "M73.8 148A74 74 0 1 0 73.7.2a74 74 0 0 0 .1 147.8z" ] []
                , Svg.path [ SA.fill "#B58A5A", SA.fillRule "evenodd", SA.d "M29.9 92.4L4.5 138.2c15.8 12.8 33.3 14.6 52.5 5.3-1-3.9-10-21-27.1-51.1z", SA.clipRule "evenodd" ] []
                , Svg.path [ SA.fill "#B58A5A", SA.fillRule "evenodd", SA.d "M29.9 92.4L4.5 138.2c6.9 9.1 15.9 11.7 27 7.8-.5-3.6-1-21.5-1.6-53.6z", SA.clipRule "evenodd" ] []
                , Svg.path [ SA.fill "#fff", SA.fillRule "evenodd", SA.d "M29.9 91.7l-9.1 17-2.6 7.2 4.3-5.8 1 9.7 3.7-10.5 4.2 9.4 1.5-8.8 2.6 4.3 1.7-4.3 3.4 4.8-1.3-5.5-9.4-17.5z", SA.clipRule "evenodd" ] []
                , Svg.path [ SA.fill "#C49A6C", SA.fillRule "evenodd", SA.d "M74.5 43.1L23.8 134c31.7 25.4 66.6 28.9 105 10.4-2-7.6-20.1-41.4-54.3-101.3z", SA.clipRule "evenodd" ] []
                , Svg.path [ SA.fill "#BD9263", SA.fillRule "evenodd", SA.d "M74.5 43.1L23.8 134c13.7 18 31.7 23.2 54 15.4-1-7.2-2.1-42.7-3.3-106.3z", SA.clipRule "evenodd" ] []
                , Svg.path [ SA.fill "#fff", SA.fillRule "evenodd", SA.d "M74.5 41.7L56.3 75.4l-5.1 14.4 8.6-11.6 2 19.2 7.5-20.8 8.3 18.6 2.9-17.4 5.3 8.6 3.3-8.6 6.9 9.5-2.6-10.8-19-34.8z", SA.clipRule "evenodd" ] []
                , Svg.g [ SA.fillRule "evenodd", SA.clipRule "evenodd" ]
                    [ Svg.path [ SA.fill "#C99F72", SA.d "M116.9 100.4l-25.4 45.8c15.8 12.8 33.3 14.6 52.5 5.3-1-3.9-10-21-27.1-51.1z" ] []
                    , Svg.path [ SA.fill "#C99F72", SA.d "M116.9 100.4l-25.4 45.8c6.9 9.1 15.9 11.7 27 7.8-.5-3.6-1-21.5-1.6-53.6z" ] []
                    , Svg.path [ SA.fill "#fff", SA.d "M116.9 99.7l-9.1 17-2.6 7.2 4.3-5.8 1 9.7 3.7-10.5 4.2 9.4 1.5-8.8 2.6 4.3 1.7-4.3 3.4 4.8-1.3-5.5-9.4-17.5z" ] []
                    ]
                , Svg.g [ SA.fillRule "evenodd", SA.clipRule "evenodd" ]
                    [ Svg.path [ SA.fill "#FFFEFB", SA.d "M74 18.8l-.1 23h-.6v2.5h2.5v-2.6h-.6v-23H74z" ] []
                    , Svg.path [ SA.fill "#BF0000", SA.d "M75.2 19.3H54.1l3 5.6-3 5.9h21.1V19.4z" ] []

                    --
                    -- Removing the rakuten logo from inside the little flag
                    --
                    -- , Svg.path [ SA.fill "#fff", SA.d "M65.7 23.6h-.5v1.3h.5c.3 0 .6-.3.6-.7 0-.4-.3-.6-.6-.6z" ] []
                    -- , Svg.path [ SA.fill "#fff", SA.d "M66.8 27l-1-1.3h-.5V27h-.8v-4.3h1.3c.8 0 1.4.7 1.4 1.5 0 .5-.2 1-.6 1.2l1.2 1.6h-1zm-1-6.1a4 4 0 0 0-3.8 4 4 4 0 0 0 3.8 4 4 4 0 0 0 3.8-4 4 4 0 0 0-3.8-4z" ] []
                    ]
                , Svg.path [ SA.fill "#FCF9E8", SA.fillRule "evenodd", SA.d "M89 42.4s.6-5 7.7-5.3c1.4-9.3 12.9-3.8 14-.4 4-1 6.2 1.4 6.6 3.9 2-.5 3.3 1.7 3.3 1.7h-26l-5.6.1zm46.1 16.8s.7-5 7.8-5.3c1.3-9.3 12.8-3.8 14-.4 4-.9 6.1 1.5 6.5 4 2-.6 3.4 1.6 3.4 1.6h-26.1l-5.6.1z", SA.clipRule "evenodd" ] []
                ]
            ]
        ]


{-| -}
greenCheck : List (Attribute (R10.Context.ContextInternal z) msg) -> Int -> Element (R10.Context.ContextInternal z) msg
greenCheck attrs size =
    R10.Svg.Utils.wrapperWithViewbox attrs
        "0 0 131 130"
        size
        [ Svg.circle [ SA.fill "#ECFBEC", SA.cx "65.5", SA.cy "65", SA.r "65" ] []
        , Svg.circle [ SA.fill "#ECFBEC", SA.cx "66", SA.cy "64.5", SA.r "40.5", SA.stroke "#00A400", SA.strokeWidth "4" ] []
        , Svg.path [ SA.fill "#ECFBEC", SA.stroke "#00A400", SA.strokeLinecap "round", SA.strokeLinejoin "round", SA.strokeWidth "4", SA.d "M44.4 65.5L59.9 81l30.6-31" ] []
        ]


{-| -}
errorTriangle : List (Attribute (R10.Context.ContextInternal z) msg) -> Int -> Element (R10.Context.ContextInternal z) msg
errorTriangle attrs size =
    R10.Svg.Utils.wrapperWithViewbox attrs
        "0 0 183 141"
        size
        [ Svg.g
            [ SA.clipPath "url(#clip0)", SA.fill "none" ]
            [ Svg.path [ SA.fill "#F4F5F6", SA.d "M32.94 75.62A11.7 11.7 0 0144.6 63.96h36.65a11.7 11.7 0 0111.67 11.66A11.7 11.7 0 0181.26 87.3h-53.7c5.38 0 5.38-5.25 5.38-11.67z" ] []
            , Svg.path [ SA.fill "#F4F5F6", SA.d "M6.91 98.96a11.7 11.7 0 0111.67-11.67H85c-6.29 0-9.12 5.25-9.12 11.67a11.7 11.7 0 01-11.67 11.67H18.58A11.7 11.7 0 016.9 98.96zM129.78 130.53v-6.38a8.5 8.5 0 018.47-8.48h13.82a8.5 8.5 0 018.47 8.48v6.38a8.5 8.5 0 01-8.47 8.47h-13.82a8.49 8.49 0 01-8.47-8.47z" ] []
            , Svg.path [ SA.fill "#C5CCD1", SA.d "M91.28 2.02h-.45c-.7 0-1.28-.58-1.28-1.29V.28a1.28 1.28 0 10-2.57 0v.44c0 .71-.57 1.29-1.28 1.29h-.44a1.28 1.28 0 100 2.56h.44c.7 0 1.28.58 1.28 1.29v.44a1.28 1.28 0 102.57 0v-.42c0-.71.57-1.29 1.28-1.29h.45a1.29 1.29 0 000-2.58z" ] []
            , Svg.path [ SA.fill "#E6E6E6", SA.d "M78.8 9.56h-.3a.82.82 0 01-.82-.82v-.29a.82.82 0 00-.82-.82.82.82 0 00-.83.82v.29c0 .46-.37.82-.83.82h-.28a.82.82 0 00-.83.83c0 .46.37.83.83.83h.28c.46 0 .83.36.83.82v.29c0 .46.37.82.83.82.45 0 .82-.36.82-.82v-.29c0-.46.37-.82.83-.82h.28c.46 0 .83-.37.83-.83a.82.82 0 00-.83-.83z" ] []
            , Svg.path [ SA.fill "#C5CCD1", SA.d "M112.33 13.19h-.44c-.71 0-1.29-.57-1.29-1.28v-.44a1.28 1.28 0 10-2.56 0v.44c0 .7-.58 1.28-1.29 1.28h-.44a1.28 1.28 0 100 2.57h.44c.71 0 1.29.57 1.29 1.28v.44a1.28 1.28 0 002.56 0v-.44c0-.7.58-1.28 1.29-1.28h.44a1.28 1.28 0 100-2.57zM133.19 4.56h-.44c-.71 0-1.29-.57-1.29-1.28v-.45a1.28 1.28 0 10-2.56 0v.44c0 .71-.58 1.29-1.29 1.29h-.44a1.28 1.28 0 100 2.56h.44c.71 0 1.29.58 1.29 1.29v.44a1.28 1.28 0 002.56 0v-.43c0-.7.58-1.28 1.29-1.28h.44a1.29 1.29 0 000-2.58z" ] []
            , Svg.path [ SA.fill "#7E8795", SA.d "M64.47 9.3h-.44c-.7 0-1.28-.58-1.28-1.29v-.44a1.28 1.28 0 10-2.57 0v.44c0 .71-.57 1.29-1.28 1.29h-.44a1.28 1.28 0 100 2.56h.44c.7 0 1.28.58 1.28 1.29v.44a1.28 1.28 0 102.57 0v-.44c0-.71.57-1.29 1.28-1.29h.44a1.28 1.28 0 100-2.56z" ] []
            , Svg.path [ SA.fill "#E6E6E6", SA.d "M102.84 6.16h-.31a.91.91 0 01-.92-.91v-.32a.91.91 0 10-1.83 0v.32c0 .5-.41.91-.92.91h-.31a.91.91 0 100 1.83h.31c.52 0 .92.42.92.92v.31a.91.91 0 101.83 0v-.31c0-.51.41-.92.92-.92h.31a.91.91 0 100-1.83z" ] []
            , Svg.path [ SA.fill "#7E8795", SA.d "M126.02 13.84h-.31a.91.91 0 01-.92-.92v-.31a.91.91 0 10-1.83 0v.31c0 .51-.4.92-.91.92h-.32a.91.91 0 100 1.83h.32c.5 0 .91.41.91.91v.32a.91.91 0 101.83 0v-.3c0-.52.42-.92.92-.92h.31a.92.92 0 000-1.84z" ] []
            , Svg.path [ SA.fill "#fff", SA.d "M85.68 35.98l-39.35 68.16a9.83 9.83 0 008.52 14.75h78.7c7.58 0 12.31-8.19 8.52-14.75l-39.35-68.16a9.83 9.83 0 00-17.04 0z" ] []
            , Svg.path [ SA.stroke "#B4B9C2", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M103.03 36.53a10.2 10.2 0 00-17.67 0l-38.72 67.05a10.2 10.2 0 008.84 15.3" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M80.1 118.89h52.82a10.2 10.2 0 008.83-15.3l-25.16-43.57" ] []
            , Svg.path [ SA.fill "#E1E5EA", SA.d "M90.4 44.64l-34.77 60.22a4.35 4.35 0 003.77 6.52h69.53a4.35 4.35 0 003.77-6.52L97.92 44.64a4.35 4.35 0 00-7.53 0z" ] []
            , Svg.path [ SA.fill "#5E6570", SA.d "M94.69 87.25c0 .13-.07.23-.22.28a1.4 1.4 0 01-.96 0c-.15-.05-.22-.15-.22-.28a147.96 147.96 0 00-.22-8.25 31.4 31.4 0 00-.27-2.51l-.34-2.25c-.13-.7-.3-1.5-.49-2.37-.19-.86-.29-1.64-.29-2.32 0-.75.2-1.38.56-1.9.37-.52.98-.78 1.83-.78.93 0 1.59.25 1.96.77.37.5.55 1.14.55 1.9 0 .31-.03.67-.1 1.1-.07.42-.15.85-.24 1.27l-.28 1.27c-.1.42-.17.8-.23 1.09l-.4 2.24c-.12.73-.23 1.56-.33 2.52a104.65 104.65 0 00-.31 8.22zm-.53 11.93a3 3 0 01-2.05-.76 2.44 2.44 0 01-.88-1.93c0-.7.27-1.34.8-1.93a2.6 2.6 0 012.01-.88c.79 0 1.49.25 2.1.74.63.48.94 1.14.94 1.96 0 .73-.28 1.39-.82 1.95-.55.58-1.25.85-2.1.85z" ] []
            ]
        , Svg.defs
            []
            [ Svg.clipPath [ SA.id "clip0" ]
                [ Svg.path [ SA.fill "#fff", SA.d "M0 0h183v140H0z", SA.transform "translate(0 .5)" ] []
                ]
            ]
        ]


{-| -}
errorLens : List (Attribute (R10.Context.ContextInternal z) msg) -> Int -> Element (R10.Context.ContextInternal z) msg
errorLens attrs size =
    R10.Svg.Utils.wrapperWithViewbox attrs
        "0 0 179 149"
        size
        [ Svg.g
            [ SA.clipPath "url(#clip0)", SA.fill "none" ]
            [ Svg.path [ SA.fill "#F4F5F6", SA.d "M91.95 42.87a8.84 8.84 0 018.8-8.84h16.9a8.84 8.84 0 010 17.67h-16.9a8.85 8.85 0 01-8.8-8.84zM38.03 130.38a8.84 8.84 0 018.8-8.83h16.9a8.84 8.84 0 010 17.67h-16.9a8.84 8.84 0 01-8.8-8.84zM109.82 138.89c0-5.18-4.45-9.42-7.83-9.42h63.31c-4.22 0-8.44 4.24-8.44 9.42a9.43 9.43 0 01-9.38 9.42h-28.3a9.42 9.42 0 01-9.36-9.42zM67.42 67.45a8.84 8.84 0 018.8-8.84h71.64c4.83 0 8.8 3.98 8.8 8.84 0 4.85 1.9 8.83 6.97 8.83H76.2a8.84 8.84 0 01-8.78-8.83zM89.42 85.2c0-4.86-2.62-8.83-7.69-8.83h88.12a8.84 8.84 0 010 17.67H81.73c4.22-.01 7.69-3.98 7.69-8.84zM55.6 102.95a8.84 8.84 0 018.8-8.83h86.55c-3.37 0-6.13 3.98-6.13 8.83 0 4.86 1.91 8.84 6.13 8.84H64.4a8.85 8.85 0 01-8.8-8.84z" ] []
            , Svg.path [ SA.fill "#F4F5F6", SA.d "M84.63 120.7c0-4.86-.36-8.83-6.27-8.83h86.7a8.84 8.84 0 010 17.67H93.42a8.84 8.84 0 01-8.8-8.84z" ] []
            , Svg.path [ SA.fill "#D7DCE0", SA.stroke "#B4B9C2", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M86.13 55.42c-.08 11.26-9.37 1.14-11.92 9.35-2.8 8.98 8.6 5.45 4.18 14.6-4.7 9.74-6.87-3.99-15.12.5-7.11 3.89 3.8 10.95-5.15 14.3-8.74 3.27-1.83-8.56-12.53-8.53-8.88.04-1.94 13.13-12.54 8.52-9.7-4.21 2.1-8.68-5.15-14.28-7.36-5.69-7.64 9.1-15.12-.51-7.31-9.4 6.67-6.07 4.18-14.6-2.7-9.23-11.93 3.57-11.93-9.35 0-11.65 9.38-.38 11.92-9.34 2.51-8.87-11.29-4-4.18-14.6 6.51-9.72 8.4 5.66 15.12-.51 5.45-5.01-5.52-11.02 5.15-14.29 12.35-3.79 4.42 8 12.53 8.52 9.88.65 2.36-12.71 12.54-8.52 11.04 4.56-1.5 9.36 5.15 14.29 7.73 5.73 7.64-7.6 15.11.5 8.1 8.78-5.6 6.69-4.17 14.6 1.6 8.9 12-.17 11.93 9.35z" ] []
            , Svg.path [ SA.fill "#F4F5F6", SA.stroke "#B4B9C2", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M45.58 65.25c5.36 0 9.7-4.36 9.7-9.74a9.72 9.72 0 00-9.7-9.75 9.72 9.72 0 00-9.7 9.75 9.72 9.72 0 009.7 9.74z" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M133.26 123.02l-26.53-26.65-4.73 4.76 26.53 26.65 4.73-4.76z" ] []
            , Svg.path [ SA.fill "#fff", SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M134.1 138.25l-15.12-15.2a6.69 6.69 0 010-9.4 6.62 6.62 0 019.36 0l15.12 15.2a6.69 6.69 0 010 9.4 6.62 6.62 0 01-9.36 0zM84.16 116.86a38.66 38.66 0 0038.57-38.75 38.66 38.66 0 00-38.57-38.75 38.66 38.66 0 00-38.58 38.75 38.66 38.66 0 0038.58 38.75z" ] []
            , Svg.path [ SA.stroke "#D7DCE0", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M61.11 75.14a19.6 19.6 0 0119.55-19.63" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M84.16 109.45a31.27 31.27 0 0031.2-31.34 31.27 31.27 0 00-31.2-31.34 31.27 31.27 0 00-31.2 31.34 31.27 31.27 0 0031.2 31.34z" ] []
            , Svg.path [ SA.fill "#7E8795", SA.d "M108.8 11.28h-.4a1.2 1.2 0 01-1.22-1.21v-.42a1.2 1.2 0 10-2.4 0v.42c0 .67-.55 1.21-1.22 1.21h-.41c-.67 0-1.2.54-1.2 1.21 0 .67.53 1.22 1.2 1.22h.41c.67 0 1.21.54 1.21 1.2v.42a1.2 1.2 0 102.42 0v-.41c0-.67.53-1.21 1.2-1.21h.42a1.21 1.21 0 000-2.43z" ] []
            , Svg.path [ SA.fill "#E6E6E6", SA.d "M97.06 18.41h-.27a.78.78 0 01-.77-.78v-.27a.78.78 0 10-1.56 0v.27c0 .43-.34.78-.77.78h-.27a.78.78 0 00-.78.78c0 .43.35.78.78.78h.27c.43 0 .77.35.77.78v.27a.78.78 0 101.56 0v-.27c0-.43.34-.78.77-.78h.27a.78.78 0 000-1.56z" ] []
            , Svg.path [ SA.fill "#C5CCD1", SA.d "M128.6 21.85h-.4c-.67 0-1.21-.55-1.21-1.22v-.41a1.2 1.2 0 10-2.42 0v.41a1.2 1.2 0 01-1.2 1.22h-.42a1.21 1.21 0 000 2.42h.42c.66 0 1.2.54 1.2 1.21v.42a1.2 1.2 0 102.42 0v-.4c0-.68.54-1.22 1.2-1.22h.42c.67 0 1.2-.54 1.2-1.21 0-.68-.53-1.22-1.2-1.22zM148.22 13.69h-.41a1.2 1.2 0 01-1.21-1.21v-.42a1.2 1.2 0 10-2.42 0v.42c0 .67-.54 1.2-1.2 1.2h-.42c-.66 0-1.2.55-1.2 1.22 0 .67.54 1.21 1.2 1.21h.42c.66 0 1.2.55 1.2 1.22v.41a1.2 1.2 0 102.42 0v-.41c0-.67.54-1.22 1.2-1.22h.42a1.21 1.21 0 000-2.42z" ] []
            , Svg.path [ SA.fill "#7E8795", SA.d "M83.6 3.16h-.41c-.67 0-1.21-.54-1.21-1.21v-.43a1.21 1.21 0 10-2.42 0v.42c0 .67-.54 1.21-1.2 1.21h-.42a1.21 1.21 0 000 2.42h.42c.66 0 1.2.55 1.2 1.22v.41a1.21 1.21 0 102.42 0v-.4c0-.67.54-1.2 1.2-1.2h.42c.67 0 1.2-.55 1.2-1.22 0-.68-.53-1.22-1.2-1.22z" ] []
            , Svg.path [ SA.fill "#E6E6E6", SA.d "M119.68 15.2h-.3a.86.86 0 01-.86-.86v-.3a.86.86 0 10-1.72 0v.3c0 .49-.39.87-.86.87h-.3a.86.86 0 00-.86.86c0 .48.39.87.86.87h.3c.48 0 .86.39.86.86v.3a.86.86 0 101.72 0v-.3c0-.48.39-.86.86-.86h.3c.48 0 .86-.4.86-.87a.86.86 0 00-.86-.86z" ] []
            , Svg.path [ SA.fill "#7E8795", SA.d "M141.7 29.15h-.3a.86.86 0 01-.86-.86v-.3a.86.86 0 10-1.72 0v.3c0 .48-.4.86-.87.86h-.3a.86.86 0 00-.85.87c0 .48.39.86.86.86h.3c.47 0 .85.4.85.87v.3a.86.86 0 101.73 0v-.3c0-.48.39-.87.86-.87h.3c.48 0 .85-.39.85-.86a.85.85 0 00-.86-.87z" ] []
            , Svg.path [ SA.fill "#5E6570", SA.d "M85.3 81.56c0 .13-.06.22-.2.27a1.3 1.3 0 01-.88 0c-.15-.05-.22-.14-.22-.27a137.45 137.45 0 00-.2-7.7c-.07-.89-.15-1.67-.25-2.35l-.3-2.1c-.13-.67-.28-1.4-.46-2.21-.18-.8-.27-1.54-.27-2.17 0-.7.17-1.28.51-1.76.35-.49.92-.73 1.7-.73.88 0 1.48.23 1.82.7.35.48.52 1.08.52 1.8 0 .28-.03.62-.1 1.01-.06.4-.14.8-.22 1.2l-.27 1.19c-.1.4-.16.74-.21 1.02l-.37 2.09a51.21 51.21 0 00-.51 5.5 96.22 96.22 0 00-.09 4.51zm-.5 11.16c-.72 0-1.35-.24-1.9-.71a2.3 2.3 0 01-.8-1.8c0-.65.24-1.25.73-1.8a2.42 2.42 0 011.88-.83c.72 0 1.37.23 1.95.69.59.46.87 1.06.87 1.83 0 .7-.25 1.3-.76 1.83-.52.52-1.17.8-1.96.8z" ] []
            ]
        , Svg.defs
            []
            [ Svg.clipPath [ SA.id "clip0" ]
                [ Svg.path [ SA.fill "#fff", SA.d "M0 0h178.62v148H0z", SA.transform "translate(.19 .5)" ] []
                ]
            ]
        ]


{-| -}
letterClosed : List (Attribute (R10.Context.ContextInternal z) msg) -> Int -> Element (R10.Context.ContextInternal z) msg
letterClosed attrs size =
    R10.Svg.Utils.wrapperWithViewbox attrs
        "0 0 237 135"
        size
        [ Svg.path [ SA.fill "#F4F5F6", SA.fillRule "evenodd", SA.d "M53.48 0a10.45 10.45 0 00-10.42 10.42c0 5.72 4.69 10.41 10.42 10.42h20.03c5.73 0 10.42-4.69 10.42-10.42C83.93 4.69 79.24 0 73.51 0H53.48zm2.38 112.64c3.85.66 8.37 5.37 8.37 11.03 0 6.11 5 11.1 11.11 11.11h33.51c6.11 0 11.11-5 11.11-11.11 0-5.66 4.29-10.37 8.9-11.03h.82c5.73 0 10.42-4.69 10.42-10.42 0-5.73-4.69-10.42-10.42-10.42H26.97c7 0 7.43 4.69 7.43 10.42 0 5.73 4.68 10.42 10.41 10.42h11.05zM14 39.41c0-5.73 4.69-10.42 10.42-10.42h84.87c5.73 0 10.42 4.69 10.42 10.42 0 5.73 2.27 10.42 8.27 10.42H24.42A10.45 10.45 0 0114 39.41zm16.96 10.52c6 0 9.1 4.69 9.1 10.42 0 5.73-4.1 10.41-9.1 10.42h104.38c5.73 0 10.42-4.69 10.42-10.42 0-5.73-4.69-10.42-10.42-10.42H30.96zM0 81.28c0-5.73 4.69-10.42 10.42-10.42h102.55c-4 0-7.27 4.69-7.27 10.42 0 5.73 2.27 10.42 7.27 10.42H10.42A10.45 10.45 0 010 81.28z", SA.clipRule "evenodd" ] []
        , Svg.path [ SA.fill "#C5CCD1", SA.d "M109.45 10.16h-.49c-.79 0-1.43-.64-1.43-1.43v-.5a1.43 1.43 0 10-2.86 0v.49c0 .79-.64 1.43-1.43 1.43h-.49a1.43 1.43 0 100 2.86h.49c.79 0 1.43.64 1.43 1.43v.49a1.43 1.43 0 102.86 0v-.49c0-.79.64-1.43 1.43-1.43h.49a1.43 1.43 0 100-2.85z" ] []
        , Svg.path [ SA.fill "#E6E6E6", SA.d "M95.54 18.57h-.32a.92.92 0 01-.92-.92v-.32a.92.92 0 00-.92-.92.92.92 0 00-.92.92v.32c0 .51-.41.92-.92.92h-.32a.92.92 0 00-.92.92c0 .51.41.92.92.92h.32c.51 0 .92.41.92.92v.32c0 .51.41.92.92.92s.92-.41.92-.92v-.32c0-.51.41-.92.92-.92h.32c.51 0 .92-.41.92-.92a.92.92 0 00-.92-.92z" ] []
        , Svg.path [ SA.fill "#C5CCD1", SA.d "M132.9 22.61h-.49c-.79 0-1.43-.64-1.43-1.43v-.49a1.43 1.43 0 10-2.86 0v.49c0 .79-.64 1.43-1.43 1.43h-.49a1.43 1.43 0 100 2.86h.49c.79 0 1.43.64 1.43 1.43v.49a1.43 1.43 0 102.86 0v-.49c0-.79.64-1.43 1.43-1.43h.49a1.43 1.43 0 100-2.86zM156.14 13h-.49c-.79 0-1.43-.64-1.43-1.43v-.49a1.43 1.43 0 10-2.86 0v.49c0 .79-.64 1.43-1.43 1.43h-.49a1.43 1.43 0 100 2.86h.49c.79 0 1.43.64 1.43 1.43v.49a1.43 1.43 0 102.86 0v-.48c0-.79.64-1.43 1.43-1.43h.49a1.43 1.43 0 000-2.87z" ] []
        , Svg.path [ SA.fill "#7E8795", SA.d "M79.58 18.27h-.49c-.79 0-1.43-.64-1.43-1.43v-.49a1.43 1.43 0 10-2.86 0v.49c0 .79-.64 1.43-1.43 1.43h-.49a1.43 1.43 0 100 2.86h.49c.79 0 1.43.64 1.43 1.43v.49a1.43 1.43 0 102.86 0v-.49c0-.79.64-1.43 1.43-1.43h.49a1.43 1.43 0 100-2.86z" ] []
        , Svg.path [ SA.fill "#E6E6E6", SA.d "M122.33 14.78h-.35c-.57 0-1.02-.46-1.02-1.02v-.35a1.02 1.02 0 10-2.04 0v.35c0 .57-.46 1.02-1.02 1.02h-.35a1.02 1.02 0 100 2.04h.35c.57 0 1.02.46 1.02 1.02v.35a1.02 1.02 0 102.04 0v-.35c0-.57.46-1.02 1.02-1.02h.35a1.02 1.02 0 100-2.04z" ] []
        , Svg.path [ SA.fill "#7E8795", SA.d "M148.16 23.33h-.35c-.57 0-1.02-.46-1.02-1.02v-.35a1.02 1.02 0 10-2.04 0v.35c0 .57-.46 1.02-1.02 1.02h-.35a1.02 1.02 0 100 2.04h.35c.57 0 1.02.46 1.02 1.02v.35a1.02 1.02 0 102.04 0v-.34c0-.57.46-1.02 1.02-1.02h.35a1.03 1.03 0 000-2.05z" ] []
        , Svg.path [ SA.fill "#fff", SA.d "M145.82 104.73H70.4a7.09 7.09 0 01-7.07-7.07V45.29a7.09 7.09 0 017.07-7.07h94.03a7.09 7.09 0 017.07 7.07v30.5" ] []
        , Svg.path [ SA.fill "none", SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M145.82 104.73H70.4a7.09 7.09 0 01-7.07-7.07V45.29a7.09 7.09 0 017.07-7.07h94.03a7.09 7.09 0 017.07 7.07v30.5" ] []
        , Svg.path [ SA.fill "#D7DCE0", SA.d "M64.14 45.92s47.36 40.21 49.73 41.01c2.37.8 6.98.8 9.02 0 2.04-.8 47.82-41.01 47.82-41.01" ] []
        , Svg.path [ SA.fill "#fff", SA.d "M63.34 44.63l48.68 32.69a9.04 9.04 0 0010.04.03l49.45-32.73" ] []
        , Svg.path [ SA.fill "none", SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M63.34 44.63l48.68 32.69a9.04 9.04 0 0010.04.03l49.45-32.73M63.34 97.51l41.54-24.97M129.34 72.54l18.37 11.32" ] []
        , Svg.path [ SA.fill "#D7DCE0", SA.d "M133.85 48.44H101v2.4h32.85v-2.4zM133.85 55.25H101v2.4h32.85v-2.4z" ] []
        , Svg.path [ SA.fill "#B4B9C2", SA.d "M166.7 113.54a16.43 16.43 0 100-32.86 16.43 16.43 0 000 32.86z" ] []
        , Svg.path [ SA.fill "none", SA.stroke "#fff", SA.strokeMiterlimit "10", SA.strokeWidth "3", SA.d "M158.69 95.91l6.4 6.41 10.42-10.41" ] []
        ]


{-| -}
letterOpen : List (Attribute (R10.Context.ContextInternal z) msg) -> Int -> Element (R10.Context.ContextInternal z) msg
letterOpen attrs size =
    R10.Svg.Utils.wrapperWithViewbox attrs
        "0 0 208 161"
        size
        [ Svg.g
            [ SA.clipPath "url(#clip0)", SA.fill "none" ]
            [ Svg.path [ SA.fill "#F4F5F6", SA.d "M53.48 47.12h20.03c5.73 0 10.42-4.67 10.42-10.37 0-5.7-4.69-10.37-10.42-10.37H53.48a10.43 10.43 0 00-10.42 10.37c0 5.7 4.69 10.37 10.42 10.37zM24.42 75.97h103.55c-6 0-8.27-4.67-8.27-10.37 0-5.7-4.69-10.37-10.42-10.37H24.42A10.44 10.44 0 0014 65.6c0 5.7 4.69 10.36 10.42 10.36zM135.34 76.07H30.96c6 0 9.1 4.67 9.1 10.37 0 5.7-4.1 10.37-9.1 10.37h104.38c5.73 0 10.42-4.67 10.42-10.37 0-5.7-4.69-10.37-10.42-10.37zM105.7 107.27c0-5.7 3.27-10.37 7.27-10.37H10.42A10.43 10.43 0 000 107.27c0 5.7 4.69 10.37 10.42 10.37h102.55c-5.01 0-7.27-4.67-7.27-10.37zM129.68 117.74H26.96c7 0 7.43 4.66 7.43 10.36 0 5.7 4.69 10.37 10.42 10.37H55.8c3.86.62 8.43 5.32 8.43 10.98 0 6.08 5 11.05 11.11 11.05h33.52c6.11 0 11.11-4.97 11.11-11.05 0-5.66 4.34-10.36 8.97-10.98h.74c5.73 0 10.42-4.66 10.42-10.37a10.43 10.43 0 00-10.42-10.36z" ] []
            , Svg.path [ SA.fill "#EDEFF1", SA.d "M122.45 14.6h-.49c-.79 0-1.43-.63-1.43-1.42v-.49c0-.78-.64-1.42-1.43-1.42-.79 0-1.43.64-1.43 1.42v.49c0 .79-.64 1.42-1.43 1.42h-.49a1.43 1.43 0 100 2.85h.49c.79 0 1.43.63 1.43 1.42v.49c0 .78.64 1.42 1.43 1.42.79 0 1.43-.64 1.43-1.42v-.49c0-.79.64-1.42 1.43-1.42h.49c.79 0 1.43-.64 1.43-1.43 0-.77-.64-1.42-1.43-1.42z" ] []
            , Svg.path [ SA.fill "#E6E6E6", SA.d "M101.54 20h-.31a.92.92 0 01-.92-.92v-.32c0-.5-.41-.91-.92-.91s-.92.4-.92.91v.32c0 .5-.41.92-.92.92h-.32a.92.92 0 100 1.83h.32c.51 0 .92.4.92.91v.32c0 .5.41.92.92.92s.92-.41.92-.92v-.32c0-.5.41-.91.92-.91h.31a.92.92 0 100-1.83zM71.54 18h-.31a.92.92 0 01-.92-.91v-.32c0-.5-.41-.91-.92-.91s-.92.4-.92.91v.32c0 .5-.41.91-.92.91h-.32a.92.92 0 100 1.84h.32c.51 0 .92.4.92.91v.32c0 .5.41.92.92.92s.92-.41.92-.92v-.32c0-.5.41-.91.92-.91h.31a.92.92 0 100-1.84z" ] []
            , Svg.path [ SA.fill "#C5CAD1", SA.d "M145.9 8.1h-.49c-.79 0-1.43-.64-1.43-1.43v-.49c0-.78-.64-1.42-1.43-1.42-.79 0-1.43.64-1.43 1.42v.5c0 .78-.64 1.41-1.43 1.41h-.49a1.43 1.43 0 100 2.85h.49c.79 0 1.43.64 1.43 1.42v.5c0 .78.64 1.41 1.43 1.41.79 0 1.43-.63 1.43-1.42v-.49c0-.78.64-1.42 1.43-1.42h.49a1.43 1.43 0 100-2.85z" ] []
            , Svg.path [ SA.fill "#B4B9C2", SA.d "M164.14 22.41h-.49c-.79 0-1.43-.63-1.43-1.42v-.49c0-.78-.64-1.42-1.43-1.42-.79 0-1.43.64-1.43 1.42V21c0 .79-.64 1.42-1.43 1.42h-.49a1.43 1.43 0 100 2.85h.49c.79 0 1.43.64 1.43 1.42v.49c0 .79.64 1.42 1.43 1.42.79 0 1.43-.63 1.43-1.42v-.49c0-.78.64-1.42 1.43-1.42h.49a1.43 1.43 0 100-2.85zM88.58 10.74h-.49c-.79 0-1.43-.64-1.43-1.42v-.5c0-.79-.64-1.42-1.43-1.42-.79 0-1.43.63-1.43 1.42v.49c0 .78-.64 1.42-1.43 1.42h-.49a1.43 1.43 0 100 2.85h.49c.79 0 1.43.63 1.43 1.42v.49c0 .78.64 1.42 1.43 1.42.79 0 1.43-.64 1.43-1.42V15c0-.79.64-1.42 1.43-1.42h.49c.79 0 1.43-.64 1.43-1.43a1.41 1.41 0 00-1.43-1.4z" ] []
            , Svg.path [ SA.fill "#E6E6E6", SA.d "M158.33 3.29h-.35c-.57 0-1.02-.46-1.02-1.02v-.35c0-.57-.46-1.02-1.02-1.02-.57 0-1.02.46-1.02 1.02v.34c0 .57-.46 1.02-1.02 1.02h-.35a1.02 1.02 0 100 2.03h.35c.57 0 1.02.46 1.02 1.01v.35c0 .57.46 1.02 1.02 1.02.57 0 1.02-.46 1.02-1.02v-.33c0-.56.46-1.01 1.02-1.01h.35a1.02 1.02 0 000-2.04z" ] []
            , Svg.path [ SA.fill "#fff", SA.d "M139.96 44.86h21.98s0-12.93-11.71-12.93" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M139.96 44.86h21.98s0-12.93-11.71-12.93" ] []
            , Svg.path [ SA.fill "#B4B9C2", SA.d "M155.26 77.7s-45.4-40.38-47.42-41.19c-2.02-.8-6.59-.8-8.94 0-2.35.8-49.31 41.19-49.31 41.19l52.38 37.8 53.29-37.8z" ] []
            , Svg.path [ SA.fill "#fff", SA.d "M68.96 117.5V54.63c0-5.61 2.03-11.04 5.71-15.3a21.53 21.53 0 0116.26-7.4h60.02s-13 .99-13 27.03v58.54" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M68.96 117.5V54.63c0-5.61 2.03-11.04 5.71-15.3a21.53 21.53 0 0116.26-7.4h60.02s-13 .99-13 27.03v58.54" ] []
            , Svg.path [ SA.fill "#fff", SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M130.82 140.54H55.4a7.07 7.07 0 01-7.07-7.03V81.4a7.07 7.07 0 017.07-7.04l47.56 41.14 46.47-41.14a7.07 7.07 0 017.07 7.04V133.64a6.8 6.8 0 01-6.78 6.78l-18.9.12z" ] []
            , Svg.path [ SA.fill "#D7DCE0", SA.d "M48.34 133.52V81.4a7.07 7.07 0 017.07-7.04l47.56 41.14" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M130.82 140.54H55.4a7.07 7.07 0 01-7.07-7.03V81.4a7.07 7.07 0 017.07-7.04l47.56 41.14 46.47-41.14a7.07 7.07 0 017.07 7.04V133.64a6.8 6.8 0 01-6.78 6.78l-18.9.12z" ] []
            , Svg.path [ SA.fill "#fff", SA.d "M156.96 133.42l-42.63-24.9s-9.37-5.95-12.37-5.95-12.08 5.94-12.08 5.94l-41.55 24.86" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M156.96 133.42l-42.63-24.9s-9.37-5.95-12.37-5.95-12.08 5.94-12.08 5.94l-41.55 24.86" ] []
            , Svg.path [ SA.stroke "#D7DCE0", SA.strokeMiterlimit "10", SA.strokeWidth "3", SA.d "M85.8 81.68h37M85.8 89.89h37" ] []
            , Svg.path [ SA.fill "#EDEFF1", SA.stroke "#EDEFF1", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M104.3 70.74c7.6 0 13.75-6.12 13.75-13.68s-6.16-13.68-13.75-13.68c-7.6 0-13.75 6.12-13.75 13.68s6.16 13.68 13.75 13.68z" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "3", SA.d "M97.59 56.05l5.37 5.34 8.71-8.67" ] []
            ]
        , Svg.defs []
            [ Svg.clipPath
                [ SA.id "clip0" ]
                [ Svg.path [ SA.fill "#fff", SA.d "M0 0h208v159.2H0z", SA.transform "translate(0 .9)" ] []
                ]
            ]
        ]


{-| -}
checkMark : List (Attribute (R10.Context.ContextInternal z) msg) -> Int -> Element (R10.Context.ContextInternal z) msg
checkMark attrs size =
    R10.Svg.Utils.wrapperWithViewbox attrs
        "0 0 183 141"
        size
        [ Svg.g
            [ SA.clipPath "url(#clip0)", SA.fill "none" ]
            [ Svg.path [ SA.fill "#F4F5F6", SA.d "M26.2 78.3c0-6.3 5.1-11.5 11.5-11.5h36.2c6.3 0 11.5 5.2 11.5 11.5s-5.2 11.4-11.5 11.4h-53c5.3 0 5.3-5.1 5.3-11.4zM.5 101.2c0-6.3 5.1-11.5 11.5-11.5h65.6c-6.3 0-9 5.2-9 11.5s-5.2 11.4-11.6 11.4H12c-6.4 0-11.5-5.1-11.5-11.4zM121.8 129.9V128c0-5.8 4.7-10.6 10.6-10.6h9.1c5.9 0 10.6 4.8 10.6 10.6v1.8c0 5.8-4.7 10.5-10.6 10.5h-9.1c-5.9 0-10.6-4.7-10.6-10.5z" ] []
            , Svg.path [ SA.fill "#fff", SA.d "M92.2 120.8A44.6 44.6 0 00137 76.4c0-24.6-20-44.5-44.8-44.5a44.6 44.6 0 00-44.7 44.5c0 24.5 20 44.4 44.7 44.4z" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M72.2 36.1A44.4 44.4 0 01134 85a44 44 0 01-24 31" ] []
            , Svg.path [ SA.stroke "#B4B9C2", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M81.8 119.6a44 44 0 01-29.3-66.2" ] []
            , Svg.path [ SA.fill "#E1E5EA", SA.d "M90.4 111.4a35.2 35.2 0 0035.4-35c0-19.4-15.9-35.1-35.4-35.1a35.2 35.2 0 00-35.3 35c0 19.4 15.8 35.1 35.3 35.1z" ] []
            , Svg.path [ SA.stroke "#5E6570", SA.strokeMiterlimit "10", SA.strokeWidth "3", SA.d "M73.2 73.8L87 87.5l22.4-22.3" ] []
            , Svg.path [ SA.fill "#C5CCD1", SA.d "M86 4h-.5c-.7 0-1.3-.6-1.3-1.3v-.4a1.3 1.3 0 00-2.5 0v.4c0 .7-.6 1.2-1.3 1.2H80c-.7 0-1.3.6-1.3 1.3 0 .7.6 1.3 1.3 1.3h.4c.7 0 1.3.5 1.3 1.2v.4c0 .7.6 1.3 1.3 1.3.7 0 1.2-.6 1.2-1.3v-.4c0-.7.6-1.2 1.3-1.2h.4A1.3 1.3 0 1086 4z" ] []
            , Svg.path [ SA.fill "#E6E6E6", SA.d "M73.6 11.4h-.3a.8.8 0 01-.8-.9v-.2c0-.5-.3-.8-.8-.8-.4 0-.8.3-.8.8v.2c0 .5-.4.9-.8.9h-.3a.8.8 0 100 1.6h.3c.4 0 .8.3.8.8v.3c0 .4.4.8.8.8.5 0 .8-.4.8-.8v-.3c0-.5.4-.8.8-.8h.3a.8.8 0 100-1.6z" ] []
            , Svg.path [ SA.fill "#C5CCD1", SA.d "M106.7 15h-.4c-.7 0-1.3-.7-1.3-1.4v-.4c0-.7-.5-1.2-1.2-1.2s-1.3.5-1.3 1.2v.4c0 .7-.6 1.3-1.3 1.3h-.4c-.7 0-1.3.6-1.3 1.3 0 .7.6 1.2 1.3 1.2h.4c.7 0 1.3.6 1.3 1.3v.4c0 .7.6 1.3 1.3 1.3.7 0 1.2-.6 1.2-1.3v-.4c0-.7.6-1.3 1.3-1.3h.4c.7 0 1.3-.5 1.3-1.2s-.6-1.3-1.3-1.3zM127.3 6.5h-.4c-.7 0-1.3-.6-1.3-1.3v-.4c0-.7-.5-1.3-1.2-1.3s-1.3.6-1.3 1.3v.4c0 .7-.6 1.2-1.3 1.2h-.4c-.7 0-1.3.6-1.3 1.3 0 .7.6 1.3 1.3 1.3h.4c.7 0 1.3.5 1.3 1.2v.4c0 .7.6 1.3 1.3 1.3.7 0 1.2-.6 1.2-1.3v-.4c0-.7.6-1.2 1.3-1.2h.4a1.3 1.3 0 100-2.5z" ] []
            , Svg.path [ SA.fill "#7E8795", SA.d "M59.5 11H59c-.7 0-1.2-.5-1.2-1.2v-.4c0-.7-.6-1.3-1.3-1.3-.7 0-1.3.6-1.3 1.3v.4c0 .7-.5 1.3-1.2 1.3h-.5c-.7 0-1.2.6-1.2 1.2 0 .7.5 1.3 1.2 1.3h.5c.7 0 1.2.6 1.2 1.3v.4c0 .7.6 1.3 1.3 1.3.7 0 1.3-.6 1.3-1.3v-.4c0-.7.5-1.3 1.2-1.3h.5c.7 0 1.3-.6 1.3-1.3 0-.6-.6-1.2-1.3-1.2z" ] []
            , Svg.path [ SA.fill "#E6E6E6", SA.d "M97.4 8H97a.9.9 0 01-.9-.9v-.3c0-.5-.4-.9-.9-.9s-.9.4-.9 1V7c0 .5-.4 1-.9 1h-.3a.9.9 0 100 1.7h.3c.5 0 1 .4 1 1v.2c0 .5.3 1 .8 1s1-.5 1-1v-.3c0-.5.3-.9.8-.9h.4a.9.9 0 100-1.8z" ] []
            , Svg.path [ SA.fill "#7E8795", SA.d "M120.2 15.5h-.3a.9.9 0 01-.9-.9v-.3c0-.5-.4-.9-.9-.9s-.9.4-.9 1v.2c0 .5-.4 1-.9 1h-.3a.9.9 0 100 1.7h.3c.5 0 1 .4 1 1v.2c0 .5.3 1 .8 1s1-.5 1-1v-.3c0-.5.3-.9.8-.9h.3c.5 0 1-.4 1-.9s-.5-.9-1-.9z" ] []
            ]
        , Svg.defs []
            [ Svg.clipPath
                [ SA.id "clip0" ]
                [ Svg.path [ SA.fill "#fff", SA.d "M0 0h183v140H0z", SA.transform "translate(0 .5)" ] []
                ]
            ]
        ]


{-| -}
rocket : List (Attribute (R10.Context.ContextInternal z) msg) -> Int -> Element (R10.Context.ContextInternal z) msg
rocket attrs size =
    R10.Svg.Utils.wrapperWithViewbox attrs
        "0 0 159 149"
        size
        [ Svg.g
            [ SA.clipPath "url(#clip0)", SA.fill "none" ]
            [ Svg.path [ SA.fill "#F4F5F6", SA.d "M33.83 38.6a8.19 8.19 0 018.16-8.16h15.69a8.19 8.19 0 018.16 8.16 8.19 8.19 0 01-8.16 8.16H41.99a8.19 8.19 0 01-8.16-8.16zM50.41 127.29c0-4.79-4.13-8.7-7.26-8.7h58.74c-3.91 0-7.83 3.91-7.83 8.7 0 4.78-3.92 8.7-8.7 8.7H59.1a8.73 8.73 0 01-8.7-8.7zM11.07 61.3a8.19 8.19 0 018.16-8.15H85.7a8.19 8.19 0 018.16 8.16c0 4.48 1.78 8.15 6.48 8.15H19.23a8.2 8.2 0 01-8.16-8.15zM31.48 77.7c0-4.48-2.43-8.16-7.13-8.16h81.76a8.19 8.19 0 018.16 8.16 8.19 8.19 0 01-8.16 8.16H24.35c3.92 0 7.13-3.68 7.13-8.16zM.1 94.1a8.19 8.19 0 018.16-8.17H88.6c-3.14 0-5.7 3.68-5.7 8.16 0 4.49 1.78 8.16 5.7 8.16H8.26A8.19 8.19 0 01.1 94.1z" ] []
            , Svg.path [ SA.fill "#F4F5F6", SA.d "M27.05 110.49c0-4.49-.34-8.16-5.82-8.16h80.44a8.19 8.19 0 018.16 8.16 8.18 8.18 0 01-8.16 8.16H35.2a8.18 8.18 0 01-8.15-8.16z" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M80.7 123.7v20.45M74.45 119.15v19.32M86.95 119.15v19.32" ] []
            , Svg.path [ SA.stroke "#B4B9C2", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M56.83 148.12a7.96 7.96 0 0115.92 0M54.91 135.63a5.68 5.68 0 1111.36 0M94.9 135.63a5.68 5.68 0 1111.36 0M86.95 148.12a7.96 7.96 0 0115.91 0M34.82 144.29a11.65 11.65 0 0123.3 0M101.92 144.29a11.65 11.65 0 0123.3 0" ] []
            , Svg.path [ SA.fill "#B4B9C2", SA.d "M72.2 103.51l1.73 5.2c.19.57.73.95 1.33.95h12.22a1.4 1.4 0 001.37-1.1l1.12-5.05" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M72.2 103.51l1.73 5.2c.19.57.73.95 1.33.95h12.22a1.4 1.4 0 001.37-1.1l1.12-5.05" ] []
            , Svg.path [ SA.fill "#fff", SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M71.82 103.51c-8.3-5.93-12.6-20.98-12.6-37.54 0-21.88 14.35-47.84 21.87-47.84 7.52 0 21.88 25.95 21.88 47.84 0 17.43-3.9 32.23-13.43 37.54H71.82z" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M58.98 66.6c0-.67-4.79 4.11-6.15 17.77-1.36 13.67 4.1 25.29 6.15 29.4 2.04 4.1.44-12.99 7.74-15.72M103.41 66.6c0-.67 4.79 4.11 6.15 17.77 1.36 13.67-4.1 25.29-6.15 29.4-2.04 4.1-.44-12.99-7.74-15.72" ] []
            , Svg.path [ SA.fill "#D7DCE0", SA.d "M81.6 103.51h-9.27c-8.31-5.93-12.61-20.98-12.61-37.54 0-21.88 14.35-47.84 21.87-47.84" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.d "M81.6 103.51h-9.27c-8.31-5.93-12.61-20.98-12.61-37.54 0-21.88 14.35-47.84 21.87-47.84" ] []
            , Svg.path [ SA.fill "#EDEFF1", SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M81.08 54.3a5.47 5.47 0 100-10.93 5.47 5.47 0 000 10.93z" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M64.15 41.32c1.47-3.75 7.56-6.83 16.9-6.83s15.55 2.9 17.01 6.83" ] []
            , Svg.path [ SA.stroke "#7E8795", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M71.82 103.51c-8.3-5.93-12.6-20.98-12.6-37.54 0-21.88 14.35-47.84 21.87-47.84 7.52 0 21.88 25.95 21.88 47.84 0 17.43-3.9 32.23-13.43 37.54H71.82z" ] []
            , Svg.path [ SA.fill "#7E8795", SA.d "M77.63 3.5h-.39c-.61 0-1.12-.5-1.12-1.11v-.4a1.12 1.12 0 10-2.24 0v.39c0 .62-.5 1.12-1.12 1.12h-.38a1.12 1.12 0 100 2.24h.38c.62 0 1.12.5 1.12 1.12v.38a1.12 1.12 0 102.24 0v-.37c0-.61.5-1.12 1.12-1.12h.39a1.12 1.12 0 000-2.25z" ] []
            , Svg.path [ SA.fill "#E6E6E6", SA.d "M66.73 10.1h-.24a.72.72 0 01-.72-.73v-.25a.72.72 0 10-1.44 0v.25c0 .4-.32.72-.72.72h-.25a.72.72 0 100 1.44h.25c.4 0 .72.32.72.72v.25a.72.72 0 101.44 0v-.25c0-.4.32-.72.72-.72h.24a.72.72 0 100-1.44z" ] []
            , Svg.path [ SA.fill "#C5CCD1", SA.d "M96 13.26h-.38c-.62 0-1.12-.5-1.12-1.12v-.39a1.12 1.12 0 10-2.24 0v.39c0 .62-.5 1.12-1.12 1.12h-.38a1.12 1.12 0 100 2.24h.38c.62 0 1.12.5 1.12 1.12V17a1.12 1.12 0 102.24 0v-.38c0-.62.5-1.12 1.12-1.12H96a1.12 1.12 0 100-2.24zM114.2 5.73h-.39c-.62 0-1.12-.5-1.12-1.12v-.39a1.12 1.12 0 10-2.24 0v.38c0 .62-.5 1.12-1.12 1.12h-.38a1.12 1.12 0 100 2.24h.38c.62 0 1.12.5 1.12 1.12v.39a1.12 1.12 0 102.24 0V9.1c0-.62.5-1.12 1.12-1.12h.39c.62 0 1.12-.5 1.12-1.12 0-.63-.5-1.13-1.12-1.13z" ] []
            , Svg.path [ SA.fill "#7E8795", SA.d "M54.24 9.86h-.38c-.62 0-1.12-.5-1.12-1.12v-.39a1.12 1.12 0 10-2.24 0v.39c0 .62-.5 1.12-1.12 1.12h-.4a1.12 1.12 0 100 2.24h.38c.62 0 1.12.5 1.12 1.12v.38a1.12 1.12 0 102.24 0v-.38c0-.62.5-1.12 1.12-1.12h.38c.62 0 1.12-.5 1.12-1.12a1.1 1.1 0 00-1.1-1.12z" ] []
            , Svg.path [ SA.fill "#E6E6E6", SA.d "M87.72 7.12h-.28a.8.8 0 01-.8-.8v-.27a.8.8 0 10-1.6 0v.28a.8.8 0 01-.8.8h-.27a.8.8 0 100 1.6h.28c.44 0 .8.35.8.8v.27a.8.8 0 101.6 0v-.28c0-.45.35-.8.8-.8h.27a.8.8 0 00.8-.8.8.8 0 00-.8-.8z" ] []
            , Svg.path [ SA.fill "#7E8795", SA.d "M108.14 20.01h-.27a.8.8 0 01-.8-.8v-.27a.8.8 0 10-1.6 0v.28a.8.8 0 01-.8.8h-.27a.8.8 0 100 1.6h.27c.45 0 .8.35.8.79v.27a.8.8 0 101.6 0v-.27c0-.45.36-.8.8-.8h.27a.8.8 0 00.8-.8c.01-.44-.35-.8-.8-.8z" ] []
            ]
        , Svg.defs []
            [ Svg.clipPath
                [ SA.id "clip0" ]
                [ Svg.path [ SA.fill "#fff", SA.d "M0 0h159v148H0z", SA.transform "translate(0 .5)" ] []
                ]
            ]
        ]


{-| -}
paperPlane : List (Attribute (R10.Context.ContextInternal z) msg) -> Int -> Element (R10.Context.ContextInternal z) msg
paperPlane attrs size =
    R10.Svg.Utils.wrapperWithViewbox attrs
        "0 0 381 200"
        size
        [ Svg.path [ SA.fill "#CCC", SA.d "M219.8 18.2h-.6c-1 0-1.8-.8-1.8-1.8v-.6a1.8 1.8 0 10-3.6 0v.6c0 1-.8 1.8-1.8 1.8h-.6a1.8 1.8 0 100 3.6h.7c1 0 1.7.8 1.7 1.8v.6a1.8 1.8 0 103.6 0v-.6c0-1 .8-1.8 1.8-1.8h.6a1.8 1.8 0 100-3.6z" ] []
        , Svg.path [ SA.fill "#E6E6E6", SA.d "M202.5 28.7h-.4c-.7 0-1.2-.5-1.2-1.2v-.4a1.2 1.2 0 00-2.3 0v.4c0 .7-.5 1.2-1.1 1.2h-.4a1.2 1.2 0 000 2.3h.4c.6 0 1.1.5 1.1 1.1v.4a1.2 1.2 0 002.3 0v-.4c0-.6.5-1.1 1.2-1.1h.4a1.2 1.2 0 000-2.3z" ] []
        , Svg.path [ SA.fill "#EDEFF1", SA.d "M249.8 71.2h-.6c-1 0-1.8-.8-1.8-1.8v-.6a1.8 1.8 0 10-3.6 0v.6c0 1-.8 1.8-1.8 1.8h-.6a1.8 1.8 0 100 3.6h.7c1 0 1.7.8 1.7 1.8v.6a1.8 1.8 0 103.6 0v-.6c0-1 .8-1.8 1.8-1.8h.6a1.8 1.8 0 100-3.6z" ] []
        , Svg.path [ SA.fill "#E6E6E6", SA.d "M237.6 51.4h-.4c-.7 0-1.3-.5-1.3-1.3v-.4c0-.7-.6-1.3-1.3-1.3-.7 0-1.3.6-1.3 1.3v.4c0 .8-.5 1.3-1.2 1.3h-.5c-.7 0-1.3.6-1.3 1.3 0 .7.6 1.3 1.3 1.3h.5c.7 0 1.2.5 1.2 1.3v.4c0 .7.6 1.3 1.3 1.3.7 0 1.3-.6 1.3-1.3v-.4c0-.8.6-1.3 1.3-1.3h.4c.7 0 1.3-.6 1.3-1.3 0-.7-.6-1.3-1.3-1.3z" ] []
        , Svg.path [ SA.fill "#7E8795", SA.d "M248.6 37.4h-.4c-.7 0-1.3-.6-1.3-1.3v-.4c0-.7-.6-1.3-1.3-1.3-.7 0-1.3.6-1.3 1.3v.4c0 .7-.5 1.3-1.2 1.3h-.5c-.7 0-1.3.6-1.3 1.3 0 .7.6 1.3 1.3 1.3h.5c.7 0 1.2.5 1.2 1.2v.5c0 .7.6 1.3 1.3 1.3.7 0 1.3-.6 1.3-1.3v-.5c0-.7.6-1.2 1.3-1.2h.4c.7 0 1.3-.6 1.3-1.3 0-.7-.6-1.3-1.3-1.3z" ] []
        , Svg.path [ SA.fill "#F4F5F6", SA.d "M183.8 121.7a13 13 0 00-13-13H130a13 13 0 00-13 13c0 7.1 0 13-6 13h-10a13 13 0 00-13 13 13 13 0 0013 13h50.8a13 13 0 0013-13c0-7.2 3.2-13 10.2-13h-4.2a13 13 0 0013-13zM217.9 177v-2a12 12 0 0112-12h10.3a12 12 0 0112 12v2a12 12 0 01-12 12h-10.3a12 12 0 01-12-12z" ] []
        , Svg.path [ SA.fill "#D7DCE0", SA.d "M224.8 38.7l-43.6 32.1 7.4 18.8 1.3-15.4 34.9-35.5z" ] []
        , Svg.path [ SA.fill "none", SA.stroke "#7E8795", SA.strokeLinejoin "round", SA.strokeMiterlimit "10", SA.strokeWidth "2", SA.d "M224.8 38.7l-34.2 35.5 24.1 5.3 9.8-40.1c.1-.3-.2-.6-.4-.5l-59 27.2 16.1 4.7 8 21.5 1.4-18.1M189.3 92.3l9.3-16.1" ] []
        , Svg.path [ SA.fill "none", SA.stroke "#7E8795", SA.strokeLinejoin "round", SA.strokeWidth "2", SA.d "M181.2 99l-1.7 1.8" ] []
        , Svg.path [ SA.fill "none", SA.stroke "#7E8795", SA.strokeDasharray "5 5", SA.strokeLinejoin "round", SA.strokeWidth "2", SA.d "M176 104.4a524 524 0 00-13.5 14.6c-3.4 4-6 14.1 0 21.5 6 7.3 20.9 3.6 31.4-2 11.4-6 28.2 1.3 21.5 12.7a53 53 0 00-9.2 24.5" ] []
        , Svg.path [ SA.fill "none", SA.stroke "#7E8795", SA.strokeLinejoin "round", SA.strokeWidth "2", SA.d "M206.3 178.2c0 .8.2 1.7.4 2.5" ] []
        ]


{-| -}
externalLink : List (Attribute (R10.Context.ContextInternal z) msg) -> Color -> Int -> Element (R10.Context.ContextInternal z) msg
externalLink attrs cl size =
    R10.Svg.Utils.wrapperWithViewbox attrs
        "0 0 16 16"
        size
        [ Svg.path [ SA.fill <| R10.Color.Utils.toCssRgba cl, SA.fillRule "evenodd", SA.d "M11 13H2V6.5h1v-1H2a1 1 0 00-1 1V13c0 .6.4 1 1 1h9c.6 0 1-.4 1-1v-1.5h-1V13z", SA.clipRule "evenodd" ] []
        , Svg.path [ SA.fill <| R10.Color.Utils.toCssRgba cl, SA.fillRule "evenodd", SA.d "M5 4h9V3H5v1zm0 5.5h9V5H5v4.5zM14 2H5a1 1 0 00-1 1v6.5c0 .6.4 1 1 1h9c.6 0 1-.4 1-1V3c0-.6-.4-1-1-1z", SA.clipRule "evenodd" ] []
        ]
